@@ -1,5 +1,5 @@
 /* This file is part of Metaproxy.
-   Copyright (C) 2005-2010 Index Data
+   Copyright (C) 2005-2012 Index Data
 
 Metaproxy is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -74,7 +74,7 @@ int main(int argc, char **argv)
         if (doc)
         {
             mp::FactoryStatic factory;
-            mp::RouterFleXML router(doc, factory, false);
+            mp::RouterFleXML router(doc, factory, false, 0);
 
 	    mp::Package pack;
 	 
