@@ -1,5 +1,5 @@
 /* This file is part of Metaproxy.
-   Copyright (C) 2005-2010 Index Data
+   Copyright (C) 2005-2012 Index Data
 
 Metaproxy is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -18,11 +18,20 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 #include "config.hpp"
 #include <metaproxy/package.hpp>
+#include <yaz/snprintf.h>
+#include <yaz/log.h>
 
-#include <iostream>
+#include <sstream>
 
 namespace mp = metaproxy_1;
 
+namespace metaproxy_1 {
+    class Package::PackageLogger : boost::noncopyable {
+        friend class Package;
+        std::string str;
+    };
+}
+
 mp::Package::Package() 
     : m_route_pos(0)
 {
@@ -39,14 +48,18 @@ mp::Package::Package(mp::Session &session, const mp::Origin &origin)
 {
 }
 
-
 mp::Package & mp::Package::copy_filter(const Package &p)
 {
-    delete m_route_pos;
-    m_route_pos = p.m_route_pos->clone();
+    p_logger = p.p_logger;
+    copy_route(p);
     return *this;
 }
 
+void mp::Package::copy_route(const Package &p)
+{
+    delete m_route_pos;
+    m_route_pos = p.m_route_pos->clone();
+}
 
 void mp::Package::move()
 {
@@ -79,18 +92,12 @@ mp::Origin mp::Package::origin() const
 {
     return m_origin;
 }
-        
+    
 mp::Origin & mp::Package::origin()
 {
     return m_origin;
 }
 
-mp::Package & mp::Package::origin(const Origin & origin)
-{
-    m_origin = origin;
-    return *this;
-}
-
 mp::Package & mp::Package::router(const mp::Router &router)
 {
     m_route_pos = router.createpos();
@@ -113,14 +120,54 @@ mp::Session mp::Package::session() const
     return m_session;
 }
 
-std::ostream& std::operator<<(std::ostream& os,  mp::Package& p)
+std::ostream& std::operator<<(std::ostream& os, const mp::Package& p)
 {
     os << p.origin() << " ";
     os << p.session().id();
     return os;
 }
 
-                
+void mp::Package::log(const char *module, int level, const char *fmt, ...)
+{
+    char buf[4096];
+    va_list ap;
+    va_start(ap, fmt);
+
+    buf[0] = ' ';
+    yaz_vsnprintf(buf + 1, sizeof(buf)-30, fmt, ap);
+
+    std::ostringstream os;
+
+    os << module << " " << *this << buf;
+
+    va_end(ap);
+    yaz_log(level, "%s", os.str().c_str());
+
+    if (p_logger)
+        p_logger->str += std::string(module) + std::string(buf) + std::string("\n");
+}
+
+void mp::Package::log_enable(void)
+{
+    p_logger.reset(new PackageLogger);
+}
+
+void mp::Package::log_write(const char *buf, size_t sz)
+{
+    if (p_logger)
+        p_logger->str += std::string(buf, sz);
+}
+
+void mp::Package::log_reset(std::string &res)
+{
+    if (p_logger)
+    {
+        res = p_logger->str;
+        // p_logger->str.clear();
+        p_logger.reset();
+    }
+}
+
 /*
  * Local variables:
  * c-basic-offset: 4
